@@ -1,8 +1,9 @@
-# -*- coding: utf-8 -*-
+"""Utilities for initialising the database"""
+from typing import Iterable, List
 from genotype.store.models import SNP
 
 
-def read_snps(sequence):
+def read_snps(sequence: List[str]) -> Iterable[SNP]:
     """Parse TAB-separated file with SNP information."""
     # remove comment lines and split into rows
     rows = (line.strip().split("\t") for line in sequence if line and not line.startswith("#"))
